==> servicecatalog-model-6.2.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingPropertiesStateFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServiceBindingPropertiesStateFluentImpl<A extends ServiceBindingPropertiesStateFluent<A>> extends BaseFluent<A> implements ServiceBindingPropertiesStateFluent<A>{
  public ServiceBindingPropertiesStateFluentImpl() {
  }
  public ServiceBindingPropertiesStateFluentImpl(ServiceBindingPropertiesState instance) {
    this.withParameterChecksum(instance.getParameterChecksum()); 
    this.withParameters(instance.getParameters()); 
    this.withUserInfo(instance.getUserInfo()); 
  }
  private String parameterChecksum;
  private Map<String,Object> parameters;
  private UserInfoBuilder userInfo;
  public String getParameterChecksum() {
    return this.parameterChecksum;
  }
  public A withParameterChecksum(String parameterChecksum) {
    this.parameterChecksum=parameterChecksum; return (A) this;
  }
  public Boolean hasParameterChecksum() {
    return this.parameterChecksum != null;
  }
  public A addToParameters(String key,Object value) {
    if(this.parameters == null && key != null && value != null) { this.parameters = new LinkedHashMap(); }
    if(key != null && value != null) {this.parameters.put(key, value);} return (A)this;
  }
  public A addToParameters(Map<String,Object> map) {
    if(this.parameters == null && map != null) { this.parameters = new LinkedHashMap(); }
    if(map != null) { this.parameters.putAll(map);} return (A)this;
  }
  public A removeFromParameters(String key) {
    if(this.parameters == null) { return (A) this; }
    if(key != null && this.parameters != null) {this.parameters.remove(key);} return (A)this;
  }
  public A removeFromParameters(Map<String,Object> map) {
    if(this.parameters == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.parameters != null){this.parameters.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getParameters() {
    return this.parameters;
  }
  public <K,V>A withParameters(Map<String,Object> parameters) {
    if (parameters == null) { this.parameters =  null;} else {this.parameters = new LinkedHashMap(parameters);} return (A) this;
  }
  public Boolean hasParameters() {
    return this.parameters != null;
  }
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public UserInfo buildUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public A withUserInfo(UserInfo userInfo) {
    _visitables.get("userInfo").remove(this.userInfo);
    if (userInfo!=null){ this.userInfo= new UserInfoBuilder(userInfo); _visitables.get("userInfo").add(this.userInfo);} else { this.userInfo = null; _visitables.get("userInfo").remove(this.userInfo); } return (A) this;
  }
  public Boolean hasUserInfo() {
    return this.userInfo != null;
  }
  public ServiceBindingPropertiesStateFluent.UserInfoNested<A> withNewUserInfo() {
    return new ServiceBindingPropertiesStateFluentImpl.UserInfoNestedImpl();
  }
  public ServiceBindingPropertiesStateFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item) {
    return new ServiceBindingPropertiesStateFluentImpl.UserInfoNestedImpl(item);
  }
  public ServiceBindingPropertiesStateFluent.UserInfoNested<A> editUserInfo() {
    return withNewUserInfoLike(getUserInfo());
  }
  public ServiceBindingPropertiesStateFluent.UserInfoNested<A> editOrNewUserInfo() {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): new UserInfoBuilder().build());
  }
  public ServiceBindingPropertiesStateFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item) {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServiceBindingPropertiesStateFluentImpl that = (ServiceBindingPropertiesStateFluentImpl) o;
    if (parameterChecksum != null ? !parameterChecksum.equals(that.parameterChecksum) :that.parameterChecksum != null) return false;
    if (parameters != null ? !parameters.equals(that.parameters) :that.parameters != null) return false;
    if (userInfo != null ? !userInfo.equals(that.userInfo) :that.userInfo != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(parameterChecksum,  parameters,  userInfo,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (parameterChecksum != null) { sb.append("parameterChecksum:"); sb.append(parameterChecksum + ","); }
    if (parameters != null && !parameters.isEmpty()) { sb.append("parameters:"); sb.append(parameters + ","); }
    if (userInfo != null) { sb.append("userInfo:"); sb.append(userInfo); }
    sb.append("}");
    return sb.toString();
  }
  class UserInfoNestedImpl<N> extends UserInfoFluentImpl<ServiceBindingPropertiesStateFluent.UserInfoNested<N>> implements ServiceBindingPropertiesStateFluent.UserInfoNested<N>,Nested<N>{
    UserInfoNestedImpl(UserInfo item) {
      this.builder = new UserInfoBuilder(this, item);
    }
    UserInfoNestedImpl() {
      this.builder = new UserInfoBuilder(this);
    }
    UserInfoBuilder builder;
    public N and() {
      return (N) ServiceBindingPropertiesStateFluentImpl.this.withUserInfo(builder.build());
    }
    public N endUserInfo() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingPropertiesStateFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServiceBindingPropertiesStateFluentImpl<A extends ServiceBindingPropertiesStateFluent<A>> extends BaseFluent<A> implements ServiceBindingPropertiesStateFluent<A>{
  public ServiceBindingPropertiesStateFluentImpl() {
  }
  public ServiceBindingPropertiesStateFluentImpl(ServiceBindingPropertiesState instance) {
    if (instance != null) {
      this.withParameterChecksum(instance.getParameterChecksum());
      this.withParameters(instance.getParameters());
      this.withUserInfo(instance.getUserInfo());
    }
  }
  private String parameterChecksum;
  private Map<String,Object> parameters;
  private UserInfoBuilder userInfo;
  public String getParameterChecksum() {
    return this.parameterChecksum;
  }
  public A withParameterChecksum(String parameterChecksum) {
    this.parameterChecksum=parameterChecksum; return (A) this;
  }
  public Boolean hasParameterChecksum() {
    return this.parameterChecksum != null;
  }
  public A addToParameters(String key,Object value) {
    if(this.parameters == null && key != null && value != null) { this.parameters = new LinkedHashMap(); }
    if(key != null && value != null) {this.parameters.put(key, value);} return (A)this;
  }
  public A addToParameters(Map<String,Object> map) {
    if(this.parameters == null && map != null) { this.parameters = new LinkedHashMap(); }
    if(map != null) { this.parameters.putAll(map);} return (A)this;
  }
  public A removeFromParameters(String key) {
    if(this.parameters == null) { return (A) this; }
    if(key != null && this.parameters != null) {this.parameters.remove(key);} return (A)this;
  }
  public A removeFromParameters(Map<String,Object> map) {
    if(this.parameters == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.parameters != null){this.parameters.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getParameters() {
    return this.parameters;
  }
  public <K,V>A withParameters(Map<String,Object> parameters) {
    if (parameters == null) { this.parameters =  null;} else {this.parameters = new LinkedHashMap(parameters);} return (A) this;
  }
  public Boolean hasParameters() {
    return this.parameters != null;
  }
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public UserInfo buildUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public A withUserInfo(UserInfo userInfo) {
    _visitables.get("userInfo").remove(this.userInfo);
    if (userInfo!=null){ this.userInfo= new UserInfoBuilder(userInfo); _visitables.get("userInfo").add(this.userInfo);} else { this.userInfo = null; _visitables.get("userInfo").remove(this.userInfo); } return (A) this;
  }
  public Boolean hasUserInfo() {
    return this.userInfo != null;
  }
  public ServiceBindingPropertiesStateFluentImpl.UserInfoNested<A> withNewUserInfo() {
    return new ServiceBindingPropertiesStateFluentImpl.UserInfoNestedImpl();
  }
  public ServiceBindingPropertiesStateFluentImpl.UserInfoNested<A> withNewUserInfoLike(UserInfo item) {
    return new ServiceBindingPropertiesStateFluentImpl.UserInfoNestedImpl(item);
  }
  public ServiceBindingPropertiesStateFluentImpl.UserInfoNested<A> editUserInfo() {
    return withNewUserInfoLike(getUserInfo());
  }
  public ServiceBindingPropertiesStateFluentImpl.UserInfoNested<A> editOrNewUserInfo() {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): new UserInfoBuilder().build());
  }
  public ServiceBindingPropertiesStateFluentImpl.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item) {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBindingPropertiesStateFluentImpl that = (ServiceBindingPropertiesStateFluentImpl) o;
    if (!java.util.Objects.equals(parameterChecksum, that.parameterChecksum)) return false;

    if (!java.util.Objects.equals(parameters, that.parameters)) return false;

    if (!java.util.Objects.equals(userInfo, that.userInfo)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(parameterChecksum,  parameters,  userInfo,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (parameterChecksum != null) { sb.append("parameterChecksum:"); sb.append(parameterChecksum + ","); }
    if (parameters != null && !parameters.isEmpty()) { sb.append("parameters:"); sb.append(parameters + ","); }
    if (userInfo != null) { sb.append("userInfo:"); sb.append(userInfo); }
    sb.append("}");
    return sb.toString();
  }
  class UserInfoNestedImpl<N> extends UserInfoFluentImpl<ServiceBindingPropertiesStateFluentImpl.UserInfoNested<N>> implements ServiceBindingPropertiesStateFluentImpl.UserInfoNested<N>,Nested<N>{
    UserInfoNestedImpl(UserInfo item) {
      this.builder = new UserInfoBuilder(this, item);
    }
    UserInfoNestedImpl() {
      this.builder = new UserInfoBuilder(this);
    }
    UserInfoBuilder builder;
    public N and() {
      return (N) ServiceBindingPropertiesStateFluentImpl.this.withUserInfo(builder.build());
    }
    public N endUserInfo() {
      return and();
    }
    
  }
  
}
